==> python-traitsgui_3.4.0.orig.tar.gz: image_info.py <==
from enthought.traits.ui.image.image import ImageInfo
from enthought.traits.ui.ui_traits   import Margin, Border 
    
images = [
    ImageInfo(
        name        = 'array_node',
        image_name  = u'@icons:array_node',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 16,
        height      = 16,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'bool_node',
        image_name  = u'@icons:bool_node',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 16,
        height      = 16,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'class_node',
        image_name  = u'@icons:class_node',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 16,
        height      = 16,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'complex_node',
        image_name  = u'@icons:complex_node',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 16,
        height      = 16,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'dialog-warning',
        image_name  = u'@icons:dialog-warning',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 32,
        height      = 32,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'dict_node',
        image_name  = u'@icons:dict_node',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 16,
        height      = 16,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'float_node',
        image_name  = u'@icons:float_node',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 16,
        height      = 16,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'folder-new',
        image_name  = u'@icons:folder-new',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 16,
        height      = 16,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'function_node',
        image_name  = u'@icons:function_node',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 16,
        height      = 16,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'int_node',
        image_name  = u'@icons:int_node',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 16,
        height      = 16,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'list_node',
        image_name  = u'@icons:list_node',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 16,
        height      = 16,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'method_node',
        image_name  = u'@icons:method_node',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 16,
        height      = 16,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'none_node',
        image_name  = u'@icons:none_node',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 16,
        height      = 16,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'object_node',
        image_name  = u'@icons:object_node',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 16,
        height      = 16,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'other_node',
        image_name  = u'@icons:other_node',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 16,
        height      = 16,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'red_ball',
        image_name  = '@icons:red_ball',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 16,
        height      = 16,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'root_node',
        image_name  = '@icons:root_node',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 16,
        height      = 16,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'set_node',
        image_name  = u'@icons:set_node',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 16,
        height      = 16,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'string_node',
        image_name  = u'@icons:string_node',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 16,
        height      = 16,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'traits_node',
        image_name  = u'@icons:traits_node',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 16,
        height      = 16,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'tuple_node',
        image_name  = u'@icons:tuple_node',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 16,
        height      = 16,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'bottom_left_origin',
        image_name  = u'@icons:bottom_left_origin',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 60,
        height      = 22,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'bottom_right_origin',
        image_name  = u'@icons:bottom_right_origin',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 60,
        height      = 22,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'top_left_origin',
        image_name  = u'@icons:top_left_origin',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 60,
        height      = 22,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'top_right_origin',
        image_name  = u'@icons:top_right_origin',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 60,
        height      = 22,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    )
]

==> python-traitsgui_3.6.0.orig.tar.gz: image_info.py <==
from enthought.traits.ui.image.image import ImageInfo
from enthought.traits.ui.ui_traits   import Margin, Border 
    
images = [
    ImageInfo(
        name        = 'BE5',
        image_name  = '@std:BE5',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 102,
        height      = 103,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'BG5',
        image_name  = '@std:BG5',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 102,
        height      = 103,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'BG6',
        image_name  = '@std:BG6',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 102,
        height      = 103,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'BH5',
        image_name  = '@std:BH5',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 102,
        height      = 102,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'BlackChromeB',
        image_name  = '@std:BlackChromeB',
        description = '',
        category    = u'Theme',
        keywords    = [u'theme'],
        width       = 271,
        height      = 271,
        border      = Border( 3, 8, 4, 11 ),
        content     = Margin( -20, -14, -16, -9 ),
        label       = Margin( -26, -22, 20, 18 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'BlackChromeT',
        image_name  = '@std:BlackChromeT',
        description = '',
        category    = u'Theme',
        keywords    = [u'theme'],
        width       = 271,
        height      = 271,
        border      = Border( 4, 7, 4, 11 ),
        content     = Margin( -20, -14, -17, -9 ),
        label       = Margin( -25, -20, 8, 22 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'BlueLabelInset',
        image_name  = '@std:BlueLabelInset',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 130,
        height      = 30,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'GG3',
        image_name  = '@std:GG3',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 102,
        height      = 102,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'GL5',
        image_name  = '@std:GL5',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 114,
        height      = 114,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'GL5T',
        image_name  = '@std:GL5T',
        description = '',
        category    = u'Theme',
        keywords    = [u'theme'],
        width       = 275,
        height      = 275,
        border      = Border( 6, 6, 6, 6 ),
        content     = Margin( 0, 1, 4, 0 ),
        label       = Margin( 15, 13, 23, 2 ),
        alignment   = 'center'
    ),
    ImageInfo(
        name        = 'GL5TB',
        image_name  = '@std:GL5TB',
        description = '',
        category    = u'Theme',
        keywords    = [u'theme'],
        width       = 275,
        height      = 275,
        border      = Border( 6, 6, 6, 6 ),
        content     = Margin( 0, 1, 4, 0 ),
        label       = Margin( 15, 13, 23, 2 ),
        alignment   = 'center'
    ),
    ImageInfo(
        name        = 'GreyItemInset',
        image_name  = '@std:GreyItemInset',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 130,
        height      = 30,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'J07',
        image_name  = '@std:J07',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 98,
        height      = 98,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'J08',
        image_name  = '@std:J08',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 100,
        height      = 100,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'J0A',
        image_name  = '@std:J0A',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 100,
        height      = 100,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'LB',
        image_name  = '@std:LB',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 200,
        height      = 18,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'LG',
        image_name  = '@std:LG',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 200,
        height      = 18,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'LT',
        image_name  = '@std:LT',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 200,
        height      = 18,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'XG0',
        image_name  = '@std:XG0',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 128,
        height      = 128,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'XG1',
        image_name  = '@std:XG1',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 128,
        height      = 128,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'alert16',
        image_name  = '@std:alert16',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 16,
        height      = 16,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'horizontal_drag',
        image_name  = '@std:horizontal_drag',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 136,
        height      = 11,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'horizontal_splitter',
        image_name  = '@std:horizontal_splitter',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 152,
        height      = 11,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'tab',
        image_name  = '@std:tab',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 134,
        height      = 131,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'tab_active',
        image_name  = '@std:tab_active',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 128,
        height      = 26,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'tab_background',
        image_name  = '@std:tab_background',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 134,
        height      = 26,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'tab_hover',
        image_name  = '@std:tab_hover',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 128,
        height      = 26,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'tab_inactive',
        image_name  = '@std:tab_inactive',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 128,
        height      = 26,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'vertical_drag',
        image_name  = '@std:vertical_drag',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 11,
        height      = 128,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'vertical_splitter',
        image_name  = '@std:vertical_splitter',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 12,
        height      = 153,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'inset_grey',
        image_name  = '@std:inset_grey',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 239,
        height      = 30,
        border      = Border( 0, 0, 0, 0 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 0, 0, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'notebook_close',
        image_name  = '@std:notebook_close',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 238,
        height      = 40,
        border      = Border( 0, 6, 0, 6 ),
        content     = Margin( 0, 0, 0, 0 ),
        label       = Margin( 4, 9, 0, 0 ),
        alignment   = 'default'
    ),
    ImageInfo(
        name        = 'notebook_open',
        image_name  = '@std:notebook_open',
        description = '',
        category    = 'General',
        keywords    = [],
        width       = 268,
        height      = 268,
        border      = Border( 0, 5, 0, 6 ),
        content     = Margin( 0, 0, 4, 2 ),
        label       = Margin( 21, 15, 12, 10 ),
        alignment   = 'center'
    )
]
